@@ -8,15 +8,35 @@
 #  http://www.ch-werner.de/xtools/cross-mingw32-3.1-4.i386.rpm
 #  http://www.ch-werner.de/xtools/nsis-2.37-1.i386.rpm
 
+# Some aspects of the build process can be controlled by shell variables:
+#
+#  NO_SQLITE2=1      omit building SQLite 2 and drivers for it
+#  NO_TCCEXT=1       omit building TCC extension
+#  SQLITE_DLLS=1     build and package drivers with SQLite 2/3 DLLs
+#  WITH_SOURCES=1    add source directory to NSIS installer
+
 set -e
 
 VER2=2.8.17
-VER3=3.7.2
+VER3=3.7.5
+VER3X=3070500
 TCCVER=0.9.24
 
+nov2=false
+if test -n "$NO_SQLITE2" ; then
+    ADD_NSIS="-DWITHOUT_SQLITE2"
+    nov2=true
+fi
+
+notcc=false
+if test -n "$NO_TCCEXT" ; then
+    ADD_NSIS="$ADD_NSIS -DWITHOUT_TCCEXT"
+    notcc=true
+fi
+
 if test -n "$SQLITE_DLLS" ; then
     export ADD_CFLAGS="-DWITHOUT_SHELL=1 -DWITH_SQLITE_DLLS=1"
-    ADD_NSIS="-DWITH_SQLITE_DLLS"
+    ADD_NSIS="$ADD_NSIS -DWITH_SQLITE_DLLS"
 fi
 
 if test -n "$WITH_SOURCES" ; then
@@ -26,16 +46,17 @@ fi
 echo "===================="
 echo "Preparing sqlite ..."
 echo "===================="
-test -r sqlite-${VER2}.tar.gz || \
+( $nov2 && echo '*** skipped (NO_SQLITE2)' ) || true
+$nov2 || test -r sqlite-${VER2}.tar.gz || \
     wget -c http://www.sqlite.org/sqlite-${VER2}.tar.gz
-test -r sqlite-${VER2}.tar.gz || exit 1
+$nov2 || test -r sqlite-${VER2}.tar.gz || exit 1
 
-rm -f sqlite
-tar xzf sqlite-${VER2}.tar.gz
-ln -sf sqlite-${VER2} sqlite
+$nov2 || rm -f sqlite
+$nov2 || tar xzf sqlite-${VER2}.tar.gz
+$nov2 || ln -sf sqlite-${VER2} sqlite
 
 # enable sqlite_encode_binary et.al.
-patch sqlite/main.mk <<'EOD'
+$nov2 || patch sqlite/main.mk <<'EOD'
 --- sqlite.orig/main.mk	2005-04-24 00:43:23.000000000 +0200
 +++ sqlite/main.mk	2006-03-16 14:29:55.000000000 +0100
 @@ -55,7 +55,7 @@
@@ -50,7 +71,7 @@ patch sqlite/main.mk <<'EOD'
 EOD
 
 # display encoding
-patch sqlite/src/shell.c <<'EOD'
+$nov2 || patch sqlite/src/shell.c <<'EOD'
 --- sqlite.orig/src/shell.c	2005-04-24 00:43:22.000000000 +0200
 +++ sqlite/src/shell.c	2006-05-23 08:22:01.000000000 +0200
 @@ -1180,6 +1180,7 @@
@@ -124,7 +145,7 @@ true || patch sqlite/src/shell.c <<'EOD'
 EOD
 
 # same but new module libshell.c
-patch sqlite/main.mk <<'EOD'
+$nov2 || patch sqlite/main.mk <<'EOD'
 --- sqlite.orig/main.mk        2007-01-10 19:30:52.000000000 +0100
 +++ sqlite/main.mk     2007-01-10 19:33:39.000000000 +0100
 @@ -54,7 +54,7 @@
@@ -137,8 +158,8 @@ patch sqlite/main.mk <<'EOD'
           main.o opcodes.o os.o pager.o parse.o pragma.o printf.o random.o \
           select.o table.o tokenize.o trigger.o update.o util.o \
 EOD
-cp -p sqlite/src/shell.c sqlite/src/libshell.c
-patch sqlite/src/libshell.c <<'EOD'
+$nov2 || cp -p sqlite/src/shell.c sqlite/src/libshell.c
+$nov2 || patch sqlite/src/libshell.c <<'EOD'
 --- sqlite.orig/src/libshell.c  2007-01-10 19:13:01.000000000 +0100
 +++ sqlite/src/libshell.c  2007-01-10 19:25:56.000000000 +0100
 @@ -20,6 +20,10 @@
@@ -181,9 +202,9 @@ patch sqlite/src/libshell.c <<'EOD'
    if( i<argc ){
 EOD
 
-rm -f sqlite/src/minshell.c
-touch sqlite/src/minshell.c
-patch sqlite/src/minshell.c <<'EOD'
+$nov2 || rm -f sqlite/src/minshell.c
+$nov2 || touch sqlite/src/minshell.c
+$nov2 || patch sqlite/src/minshell.c <<'EOD'
 --- sqlite.orig/src/minshell.c  2007-01-10 18:46:47.000000000 +0100
 +++ sqlite/src/minshell.c  2007-01-10 18:46:47.000000000 +0100
 @@ -0,0 +1,20 @@
@@ -212,9 +233,9 @@ EOD
 echo "====================="
 echo "Preparing sqlite3 ..."
 echo "====================="
-test -r sqlite-${VER3}.tar.gz || \
-    wget -c http://www.sqlite.org/sqlite-${VER3}.tar.gz
-test -r sqlite-${VER3}.tar.gz || exit 1
+test -r sqlite-src-${VER3X}.zip || \
+    wget -c http://www.sqlite.org/sqlite-src-${VER3X}.zip
+test -r sqlite-src-${VER3X}.zip || exit 1
 test -r extension-functions.c ||
     wget -O extension-functions.c -c \
       'http://www.sqlite.org/contrib/download/extension-functions.c?get=25'
@@ -225,8 +246,9 @@ fi
 test -r extfunc.c || exit 1
 
 rm -f sqlite3
-tar xzf sqlite-${VER3}.tar.gz
-ln -sf sqlite-${VER3} sqlite3
+rm -rf sqlite-src-${VER3X}
+unzip sqlite-src-${VER3X}.zip
+ln -sf sqlite-src-${VER3X} sqlite3
 
 patch sqlite3/main.mk <<'EOD'
 --- sqlite3.orig/main.mk        2007-03-31 14:32:21.000000000 +0200
@@ -409,7 +431,8 @@ test "$VER3" != "3.6.15" -a "$VER3" != "3.6.16" -a "$VER3" != "3.6.17" \
   -a "$VER3" != "3.6.18" -a "$VER3" != "3.6.19" -a "$VER3" != "3.6.20" \
   -a "$VER3" != "3.6.21" -a "$VER3" != "3.6.22" -a "$VER3" != "3.6.23" \
   -a "$VER3" != "3.6.23.1" -a "$VER3" != "3.7.0" -a "$VER3" != "3.7.0.1" \
-  -a "$VER3" != "3.7.1" -a "$VER3" != "3.7.2" \
+  -a "$VER3" != "3.7.1" -a "$VER3" != "3.7.2" -a "$VER3" != "3.7.3" \
+  -a "$VER3" != "3.7.4" -a "$VER3" != "3.7.5" \
   && patch -d sqlite3 -p1 <<'EOD'
 diff -u sqlite3.orig/src/build.c sqlite3/src/build.c
 --- sqlite3.orig/src/build.c	2007-01-09 14:53:04.000000000 +0100
@@ -474,7 +497,7 @@ diff -u sqlite3.orig/src/tclsqlite.c sqlite3/src/tclsqlite.c
 +++ sqlite3/src/tclsqlite.c	2007-04-10 07:47:49.000000000 +0200
 @@ -14,6 +14,7 @@
  **
- ** $Id: mingw-cross-build.sh,v 1.51 2010/08/24 13:25:30 chw Exp chw $
+ ** $Id: mingw-cross-build.sh,v 1.54 2011/03/10 12:31:31 chw Exp chw $
  */
 +#ifndef NO_TCL     /* Omit this whole file if TCL is unavailable */
  #include "tcl.h"
@@ -623,7 +646,8 @@ EOD
 # patch: compile fix for FTS3 as extension module
 test "$VER3" != "3.6.21" -a "$VER3" != "3.6.22" -a "$VER3" != "3.6.23" \
   -a "$VER3" != "3.6.23.1" -a "$VER3" != "3.7.0" -a "$VER3" != "3.7.0.1" \
-  -a "$VER3" != "3.7.1" -a "$VER3" != "3.7.2" \
+  -a "$VER3" != "3.7.1" -a "$VER3" != "3.7.2" -a "$VER3" != "3.7.3" \
+  -a "$VER3" != "3.7.4" -a "$VER3" != "3.7.5" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c 2008-02-02 17:24:34.000000000 +0100
 +++ sqlite3/ext/fts3/fts3.c      2008-03-16 11:29:02.000000000 +0100
@@ -650,7 +674,8 @@ test "$VER3" != "3.6.21" -a "$VER3" != "3.6.22" -a "$VER3" != "3.6.23" \
 EOD
 test "$VER3" = "3.6.21" -o "$VER3" = "3.6.22" -o "$VER3" = "3.6.23" \
   -o "$VER3" = "3.6.23.1" -o "$VER3" = "3.7.0" -o "$VER3" = "3.7.0.1" \
-  -o "$VER3" = "3.7.1" -o "$VER3" = "3.7.2" \
+  -o "$VER3" = "3.7.1" -o "$VER3" = "3.7.2" -o "$VER3" = "3.7.3" \
+  -o "$VER3" = "3.7.4" -o "$VER3" = "3.7.5" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c 2008-02-02 17:24:34.000000000 +0100
 +++ sqlite3/ext/fts3/fts3.c      2008-03-16 11:29:02.000000000 +0100
@@ -735,7 +760,8 @@ test "$VER3" = "3.6.21" && patch -d sqlite3 -p1 <<'EOD'
 EOD
 test "$VER3" = "3.6.22" -o "$VER3" = "3.6.23" -o "$VER3" = "3.6.23.1" \
   -o "$VER3" = "3.7.0" -o "$VER3" = "3.7.0.1" \
-  -o "$VER3" = "3.7.1" -o "$VER3" = "3.7.2" \
+  -o "$VER3" = "3.7.1" -o "$VER3" = "3.7.2" -o "$VER3" = "3.7.3" \
+  -o "$VER3" = "3.7.4" -o "$VER3" = "3.7.5" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_write.c   2010-01-05 09:42:19.000000000 +0100
 +++ sqlite3/ext/fts3/fts3_write.c        2010-01-05 09:55:25.000000000 +0100
@@ -775,7 +801,7 @@ test "$VER3" = "3.6.22" -o "$VER3" = "3.6.23" -o "$VER3" = "3.6.23.1" \
 EOD
 test "$VER3" = "3.6.21" -o "$VER3" = "3.6.22" -o "$VER3" = "3.6.23" \
   -o "$VER3" = "3.6.23.1" -o "$VER3" = "3.7.0" -o "$VER3" = "3.7.0.1" \
-  -o "$VER3" = "3.7.1" -o "$VER3" = "3.7.2" \
+  -o "$VER3" = "3.7.1" -o "$VER3" = "3.7.2" -o "$VER3" = "3.7.3" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_snippet.c 2009-12-03 12:33:32.000000000 +0100
 +++ sqlite3/ext/fts3/fts3_snippet.c      2010-01-05 08:03:51.000000000 +0100
@@ -835,6 +861,118 @@ test "$VER3" = "3.6.21" -o "$VER3" = "3.6.22" -o "$VER3" = "3.6.23" \
      zCopy = sqlite3_mprintf("%s", &z[8]);
 EOD
 
+test "$VER3" = "3.7.4" -o "$VER3" = "3.7.5" \
+  && patch -d sqlite3 -p1 <<'EOD'
+--- sqlite3.orig/ext/fts3/fts3_snippet.c 2009-12-03 12:33:32.000000000 +0100
++++ sqlite3/ext/fts3/fts3_snippet.c      2010-01-05 08:03:51.000000000 +0100
+@@ -14,6 +14,10 @@
+ #if !defined(SQLITE_CORE) || defined(SQLITE_ENABLE_FTS3)
+ 
+ #include "fts3Int.h"
++#include "sqlite3ext.h"
++#ifndef SQLITE_CORE
++extern const sqlite3_api_routines *sqlite3_api;
++#endif
+ #include <string.h>
+ #include <assert.h>
+ #include <ctype.h>
+--- sqlite3.orig/ext/fts3/fts3_tokenizer.c       2009-12-07 17:38:46.000000000 +0100
++++ sqlite3/ext/fts3/fts3_tokenizer.c    2010-01-05 08:12:50.000000000 +0100
+@@ -27,7 +27,7 @@
+ 
+ #include "sqlite3ext.h"
+ #ifndef SQLITE_CORE
+-  SQLITE_EXTENSION_INIT1
++extern const sqlite3_api_routines *sqlite3_api;
+ #endif
+ 
+ #include "fts3Int.h"
+--- sqlite3.orig/ext/fts3/fts3_expr.c    2009-12-03 12:33:32.000000000 +0100
++++ sqlite3/ext/fts3/fts3_expr.c 2010-01-05 08:06:10.000000000 +0100
+@@ -17,6 +17,11 @@
+ */
+ #if !defined(SQLITE_CORE) || defined(SQLITE_ENABLE_FTS3)
+ 
++#include "sqlite3ext.h"
++#ifndef SQLITE_CORE
++extern const sqlite3_api_routines *sqlite3_api;
++#endif
++
+ /*
+ ** By default, this module parses the legacy syntax that has been 
+ ** traditionally used by fts3. Or, if SQLITE_ENABLE_FTS3_PARENTHESIS
+@@ -445,7 +450,7 @@
+     const char *zStr = pParse->azCol[ii];
+     int nStr = (int)strlen(zStr);
+     if( nInput>nStr && zInput[nStr]==':' 
+-     && sqlite3_strnicmp(zStr, zInput, nStr)==0 
++     && memcmp(zStr, zInput, nStr)==0 
+     ){
+       iCol = ii;
+       iColLen = (int)((zInput - z) + nStr + 1);
+--- sqlite3.orig/ext/fts3/fts3.c	2010-12-07 16:14:36.000000000 +0100
++++ sqlite3/ext/fts3/fts3.c	2010-12-16 11:59:02.000000000 +0100
+@@ -702,8 +698,8 @@
+   sqlite3_tokenizer *pTokenizer = 0;        /* Tokenizer for this table */
+ 
+   assert( strlen(argv[0])==4 );
+-  assert( (sqlite3_strnicmp(argv[0], "fts4", 4)==0 && isFts4)
+-       || (sqlite3_strnicmp(argv[0], "fts3", 4)==0 && !isFts4)
++  assert( (strnicmp(argv[0], "fts4", 4)==0 && isFts4)
++       || (strnicmp(argv[0], "fts3", 4)==0 && !isFts4)
+   );
+ 
+   nDb = (int)strlen(argv[1]) + 1;
+@@ -732,7 +728,7 @@
+     /* Check if this is a tokenizer specification */
+     if( !pTokenizer 
+      && strlen(z)>8
+-     && 0==sqlite3_strnicmp(z, "tokenize", 8) 
++     && 0==strnicmp(z, "tokenize", 8) 
+      && 0==sqlite3Fts3IsIdChar(z[8])
+     ){
+       rc = sqlite3Fts3InitTokenizer(pHash, &z[9], &pTokenizer, pzErr);
+@@ -744,8 +740,8 @@
+         rc = SQLITE_NOMEM;
+         goto fts3_init_out;
+       }
+-      if( nKey==9 && 0==sqlite3_strnicmp(z, "matchinfo", 9) ){
+-        if( strlen(zVal)==4 && 0==sqlite3_strnicmp(zVal, "fts3", 4) ){
++      if( nKey==9 && 0==strnicmp(z, "matchinfo", 9) ){
++        if( strlen(zVal)==4 && 0==strnicmp(zVal, "fts3", 4) ){
+           bNoDocsize = 1;
+         }else{
+           *pzErr = sqlite3_mprintf("unrecognized matchinfo: %s", zVal);
+--- sqlite3.orig/ext/fts3/fts3_write.c	2010-12-16 12:08:45.000000000 +0100
++++ sqlite3/ext/fts3/fts3_write.c	2010-12-16 12:48:30.000000000 +0100
+@@ -868,16 +868,16 @@
+   assert( pnBlob);
+ 
+   if( p->pSegments ){
+-    rc = sqlite3_blob_reopen(p->pSegments, iBlockid);
+-  }else{
+-    if( 0==p->zSegmentsTbl ){
+-      p->zSegmentsTbl = sqlite3_mprintf("%s_segments", p->zName);
+-      if( 0==p->zSegmentsTbl ) return SQLITE_NOMEM;
+-    }
+-    rc = sqlite3_blob_open(
+-       p->db, p->zDb, p->zSegmentsTbl, "block", iBlockid, 0, &p->pSegments
+-    );
++    sqlite3_blob_close(p->pSegments);
++    p->pSegments = 0;
+   }
++  if( 0==p->zSegmentsTbl ){
++    p->zSegmentsTbl = sqlite3_mprintf("%s_segments", p->zName);
++    if( 0==p->zSegmentsTbl ) return SQLITE_NOMEM;
++  }
++  rc = sqlite3_blob_open(
++     p->db, p->zDb, p->zSegmentsTbl, "block", iBlockid, 0, &p->pSegments
++  );
+ 
+   if( rc==SQLITE_OK ){
+     int nByte = sqlite3_blob_bytes(p->pSegments);
+EOD
+
 # patch: FTS3 again, for SQLite3 >= 3.6.8
 test "$VER3" = "3.6.8" -o "$VER3" = "3.6.9" -o "$VER3" = "3.6.10" \
   -o "$VER3" = "3.6.11" -o "$VER3" = "3.6.12" -o "$VER3" = "3.6.13" \
@@ -887,23 +1025,49 @@ patch -d sqlite3 -p1 <<'EOD'
    char **pzErrMsg,
 EOD
 
+# patch: compile fix for rtree as extension module
+test "$VER3" = "3.7.3" -o "$VER3" = "3.7.4" -o "$VER3" = "3.7.5" && \
+  patch -d sqlite3 -p1 <<'EOD'
+--- sqlite3.orig/ext/rtree/rtree.c	2010-10-16 10:53:54.000000000 +0200
++++ sqlite3/ext/rtree/rtree.c	2010-10-16 11:12:32.000000000 +0200
+@@ -3193,6 +3193,8 @@
+   return rc;
+ }
+ 
++#ifdef SQLITE_CORE
++
+ /*
+ ** A version of sqlite3_free() that can be used as a callback. This is used
+ ** in two places - as the destructor for the blob value returned by the
+@@ -3257,6 +3259,8 @@
+   );
+ }
+ 
++#endif
++
+ #ifndef SQLITE_CORE
+ int sqlite3_extension_init(
+   sqlite3 *db,
+EOD
+
 echo "===================="
 echo "Preparing TinyCC ..."
 echo "===================="
-test -r tcc-${TCCVER}.tar.bz2 || \
+( $notcc && echo '*** skipped (NO_TCCEXT)' ) || true
+$notcc || test -r tcc-${TCCVER}.tar.bz2 || \
     wget -c http://download.savannah.nongnu.org/releases/tinycc/tcc-${TCCVER}.tar.bz2
-test -r tcc-${TCCVER}.tar.bz2 || exit 1
+$notcc || test -r tcc-${TCCVER}.tar.bz2 || exit 1
 
-rm -rf tcc tcc-${TCCVER}
-tar xjf tcc-${TCCVER}.tar.bz2
-ln -sf tcc-${TCCVER} tcc
-patch -d tcc -p1 < tcc-${TCCVER}.patch
+$notcc || rm -rf tcc tcc-${TCCVER}
+$notcc || tar xjf tcc-${TCCVER}.tar.bz2
+$notcc || ln -sf tcc-${TCCVER} tcc
+$notcc || patch -d tcc -p1 < tcc-${TCCVER}.patch
 
 echo "========================"
 echo "Cleanup before build ..."
 echo "========================"
 make -f Makefile.mingw-cross clean
-make -C sqlite -f ../mf-sqlite.mingw-cross clean
+$notv2 || make -C sqlite -f ../mf-sqlite.mingw-cross clean
 make -C sqlite3 -f ../mf-sqlite3.mingw-cross clean
 make -C sqlite3 -f ../mf-sqlite3fts.mingw-cross clean
 make -C sqlite3 -f ../mf-sqlite3rtree.mingw-cross clean
@@ -912,9 +1076,10 @@ make -f mf-sqlite3extfunc.mingw-cross clean
 echo "============================="
 echo "Building SQLite 2 ... ISO8859"
 echo "============================="
-make -C sqlite -f ../mf-sqlite.mingw-cross all
+( $nov2 && echo '*** skipped (NO_SQLITE2)' ) || true
+$nov2 || make -C sqlite -f ../mf-sqlite.mingw-cross all
 if test -n "$SQLITE_DLLS" ; then
-    make -C sqlite -f ../mf-sqlite.mingw-cross sqlite.dll
+    $nov2 || make -C sqlite -f ../mf-sqlite.mingw-cross sqlite.dll
 fi
 
 echo "====================="
@@ -930,32 +1095,40 @@ fi
 echo "==================="
 echo "Building TinyCC ..."
 echo "==================="
-( cd tcc ; sh mingw-cross-build.sh )
+( $notcc && echo '*** skipped (NO_TCCEXT)' ) || true
+$notcc || ( cd tcc ; sh mingw-cross-build.sh )
 # copy SQLite headers into TCC install include directory
-cp -p sqlite/sqlite.h TCC/include
-cp -p sqlite3/sqlite3.h sqlite3/src/sqlite3ext.h TCC/include
+$notcc || $nov2 || cp -p sqlite/sqlite.h TCC/include
+$notcc || cp -p sqlite3/sqlite3.h sqlite3/src/sqlite3ext.h TCC/include
 # copy LGPL to TCC install doc directory
-cp -p tcc-${TCCVER}/COPYING TCC/doc
+$notcc || cp -p tcc-${TCCVER}/COPYING TCC/doc
 
 echo "==============================="
 echo "Building ODBC drivers and utils"
 echo "==============================="
-make -f Makefile.mingw-cross
+if $nov2 ; then
+    make -f Makefile.mingw-cross all_no2
+else
+    make -f Makefile.mingw-cross
+fi
 make -f Makefile.mingw-cross sqlite3odbcnw.dll
 
 echo "=========================="
 echo "Building SQLite 2 ... UTF8"
 echo "=========================="
-make -C sqlite -f ../mf-sqlite.mingw-cross clean
-make -C sqlite -f ../mf-sqlite.mingw-cross ENCODING=UTF8 all
+( $nov2 && echo '*** skipped (NO_SQLITE2)' ) || true
+$nov2 || make -C sqlite -f ../mf-sqlite.mingw-cross clean
+$nov2 || make -C sqlite -f ../mf-sqlite.mingw-cross ENCODING=UTF8 all
 if test -n "$SQLITE_DLLS" ; then
-    make -C sqlite -f ../mf-sqlite.mingw-cross ENCODING=UTF8 sqliteu.dll
+    $nov2 || \
+       make -C sqlite -f ../mf-sqlite.mingw-cross ENCODING=UTF8 sqliteu.dll
 fi
 
 echo "========================="
 echo "Building drivers ... UTF8"
 echo "========================="
-make -f Makefile.mingw-cross sqliteodbcu.dll sqliteu.exe
+( $nov2 && echo '*** skipped (NO_SQLITE2)' ) || true
+$nov2 || make -f Makefile.mingw-cross sqliteodbcu.dll sqliteu.exe
 
 echo "==================================="
 echo "Building SQLite3 FTS extensions ..."
@@ -979,27 +1152,32 @@ echo "Building DLL import defs ..."
 echo "============================"
 # requires wine: create .def files with tiny_impdef.exe
 # for all .dll files which provide SQLite
-wine TCC/tiny_impdef.exe sqliteodbc.dll -o TCC/lib/sqlite.def
-wine TCC/tiny_impdef.exe sqliteodbcu.dll -o TCC/lib/sqliteu.def
-wine TCC/tiny_impdef.exe sqlite3odbc.dll -o TCC/lib/sqlite3.def
+( $notcc && echo '*** skipped (NO_TCCEXT)' ) || true
+$notcc || $nov2 || wine TCC/tiny_impdef.exe \
+  sqliteodbc.dll -o TCC/lib/sqlite.def
+$notcc || $nov2 || wine TCC/tiny_impdef.exe \
+  sqliteodbcu.dll -o TCC/lib/sqliteu.def
+$notcc || wine TCC/tiny_impdef.exe sqlite3odbc.dll -o TCC/lib/sqlite3.def
 
 if test -n "$SQLITE_DLLS" ; then
-    mv sqlite/sqlite.dll .
-    mv sqlite/sqliteu.dll .
+    $nov2 || mv sqlite/sqlite.dll .
+    $nov2 || mv sqlite/sqliteu.dll .
     mv sqlite3/sqlite3.dll .
 fi
 
 if test -n "$SQLITE_DLLS" ; then
-    wine TCC/tiny_impdef.exe sqlite.dll -o TCC/lib/sqlite.def
-    wine TCC/tiny_impdef.exe sqliteu.dll -o TCC/lib/sqliteu.def
-    wine TCC/tiny_impdef.exe sqlite3.dll -o TCC/lib/sqlite3.def
+    $notcc || $nov2 || wine TCC/tiny_impdef.exe \
+      sqlite.dll -o TCC/lib/sqlite.def
+    $notcc || $nov2 || wine TCC/tiny_impdef.exe \
+      sqliteu.dll -o TCC/lib/sqliteu.def
+    $notcc || wine TCC/tiny_impdef.exe sqlite3.dll -o TCC/lib/sqlite3.def
 fi
 
 echo "======================="
 echo "Cleanup after build ..."
 echo "======================="
-make -C sqlite -f ../mf-sqlite.mingw-cross clean
-rm -f sqlite/sqlite.exe
+$nov2 || make -C sqlite -f ../mf-sqlite.mingw-cross clean
+$nov2 || rm -f sqlite/sqlite.exe
 mv sqlite3/sqlite3.c sqlite3/sqlite3.amalg
 make -C sqlite3 -f ../mf-sqlite3.mingw-cross clean
 rm -f sqlite3/sqlite3.exe
@@ -1012,8 +1190,10 @@ echo "==========================="
 echo "Creating NSIS installer ..."
 echo "==========================="
 cp -p README readme.txt
-unix2dos < license.terms > license.txt
-unix2dos -k TCC/doc/COPYING
-unix2dos -k TCC/doc/readme.txt
+unix2dos < license.terms > license.txt || todos < license.terms > license.txt
+$notcc || unix2dos -k TCC/doc/COPYING || unix2dos -p TCC/doc/COPYING || \
+  todos -p TCC/doc/COPYING
+$notcc || unix2dos -k TCC/doc/readme.txt || unix2dos -p TCC/doc/readme.txt || \
+  todos -p TCC/doc/readme.txt
 makensis $ADD_NSIS sqliteodbc.nsi
 
