@@ -15,9 +15,9 @@
  * @file sqlite3odbc.h
  * Header file for SQLite3 ODBC driver.
  *
- * $Id: sqlite3odbc.h,v 1.27 2009/01/08 11:57:14 chw Exp chw $
+ * $Id: sqlite3odbc.h,v 1.34 2011/03/10 12:25:00 chw Exp chw $
  *
- * Copyright (c) 2004-2009 Christian Werner <chw@ch-werner.de>
+ * Copyright (c) 2004-2011 Christian Werner <chw@ch-werner.de>
  *
  * See the file "license.terms" for information on usage
  * and redistribution of this file and for a
@@ -131,16 +131,21 @@ typedef struct dbc {
     int shortnames;		/**< Always use short column names */
     int longnames;		/**< Don't shorten column names */
     int nocreat;		/**< Don't auto create database file */
+    int fksupport;		/**< Foreign keys on or off */
     int curtype;		/**< Default cursor type */
     int step_enable;		/**< True for sqlite_compile/step/finalize */
     int trans_disable;		/**< True for no transaction support */
+    int oemcp;			/**< True for Win32 OEM CP translation */
     struct stmt *cur_s3stmt;	/**< Current STMT executing sqlite statement */
-    int s3stmt_rownum;		/**< Current row number */
+    int s3stmt_needmeta;	/**< True to get meta data in s3stmt_step(). */
     FILE *trace;		/**< sqlite3_trace() file pointer or NULL */
 #ifdef USE_DLOPEN_FOR_GPPS
     void *instlib;
     int (*gpps)();
 #endif
+#if defined(_WIN32) || defined(_WIN64)
+    int xcelqrx;
+#endif
 } DBC;
 
 /**
@@ -220,6 +225,7 @@ typedef struct stmt {
     SQLCHAR cursorname[32];	/**< Cursor name */
     SQLCHAR *query;		/**< Current query, raw string */
     int *ov3;			/**< True for SQL_OV_ODBC3 */
+    int *oemcp;			/**< True for Win32 OEM CP translation */
     int isselect;		/**< > 0 if query is a SELECT statement */
     int ncols;			/**< Number of result columns */
     COL *cols;			/**< Result column array */
@@ -251,6 +257,7 @@ typedef struct stmt {
     SQLUINTEGER paramset_size;	/**< SQL_ATTR_PARAMSET_SIZE */
     SQLUINTEGER paramset_count;	/**< Internal for paramset */
     SQLUINTEGER paramset_nrows;	/**< Row count for paramset handling */
+    SQLUINTEGER max_rows;	/**< SQL_ATTR_MAX_ROWS */
     SQLUINTEGER bind_type;	/**< SQL_ATTR_ROW_BIND_TYPE */
     SQLUINTEGER *bind_offs;	/**< SQL_ATTR_ROW_BIND_OFFSET_PTR */
     /* Dummies to make ADO happy */
@@ -258,8 +265,11 @@ typedef struct stmt {
     SQLUSMALLINT *parm_oper;	/**< SQL_ATTR_PARAM_OPERATION_PTR */
     SQLUSMALLINT *parm_status;	/**< SQL_ATTR_PARAMS_STATUS_PTR */
     SQLUINTEGER *parm_proc;	/**< SQL_ATTR_PARAMS_PROCESSED_PTR */
+    SQLUINTEGER parm_bind_type;	/**< SQL_ATTR_PARAM_BIND_TYPE */
     int curtype;		/**< Cursor type */
     sqlite3_stmt *s3stmt;	/**< SQLite statement handle or NULL */
+    int s3stmt_noreset;		/**< False when sqlite3_reset() needed. */
+    int s3stmt_rownum;		/**< Current row number */
     char *bincell;		/**< Cache for blob data */
     char *bincache;		/**< Cache for blob data */
     int binlen;			/**< Length of blob data */
