@@ -15,9 +15,9 @@
  * @file sqliteodbc.h
  * Header file for SQLite ODBC driver.
  *
- * $Id: sqliteodbc.h,v 1.51 2009/01/08 11:57:14 chw Exp chw $
+ * $Id: sqliteodbc.h,v 1.54 2011/03/09 07:02:55 chw Exp chw $
  *
- * Copyright (c) 2001-2009 Christian Werner <chw@ch-werner.de>
+ * Copyright (c) 2001-2011 Christian Werner <chw@ch-werner.de>
  *
  * See the file "license.terms" for information on usage
  * and redistribution of this file and for a
@@ -156,6 +156,9 @@ typedef struct dbc {
     void *instlib;
     int (*gpps)();
 #endif
+#if defined(_WIN32) || defined(_WIN64)
+    int xcelqrx;
+#endif
 } DBC;
 
 /**
@@ -268,6 +271,7 @@ typedef struct stmt {
     SQLUSMALLINT *parm_oper;	/**< SQL_ATTR_PARAM_OPERATION_PTR */
     SQLUSMALLINT *parm_status;	/**< SQL_ATTR_PARAMS_STATUS_PTR */
     SQLUINTEGER *parm_proc;	/**< SQL_ATTR_PARAMS_PROCESSED_PTR */
+    SQLUINTEGER parm_bind_type;	/**< SQL_ATTR_PARAM_BIND_TYPE */
     int curtype;		/**< Cursor type */
     sqlite_vm *vm;		/**< SQLite VM or NULL */
 #if HAVE_ENCDEC
